Coffea by Example
=================

The following pages are rendered jupyter notebooks that provide example usage of Coffea features.

.. toctree::

   notebooks/histograms.ipynb
   notebooks/processor.ipynb
   notebooks/nanoevents.ipynb
   notebooks/applying_corrections.ipynb
